@@ -17,7 +17,8 @@ from rich.panel import Panel
 # Internal utilities
 from StreamingCommunity.Util.config_json import config_manager
 from StreamingCommunity.Util.headers import get_userAgent
-from StreamingCommunity.Util.os import compute_sha1_hash, os_manager, internet_manager
+from StreamingCommunity.Util.http_client import create_client
+from StreamingCommunity.Util.os import os_manager, internet_manager
 from StreamingCommunity.TelegramHelp.telegram_bot import get_bot_instance
 
 
@@ -33,15 +34,13 @@ from .segments import M3U8_Segments
 
 
 # Config
-ENABLE_AUDIO = config_manager.get_bool('M3U8_DOWNLOAD', 'download_audio')
 ENABLE_SUBTITLE = config_manager.get_bool('M3U8_DOWNLOAD', 'download_subtitle')
 DOWNLOAD_SPECIFIC_AUDIO = config_manager.get_list('M3U8_DOWNLOAD', 'specific_list_audio')
 DOWNLOAD_SPECIFIC_SUBTITLE = config_manager.get_list('M3U8_DOWNLOAD', 'specific_list_subtitles')
-MERGE_AUDIO = config_manager.get_bool('M3U8_DOWNLOAD', 'merge_audio')
 MERGE_SUBTITLE = config_manager.get_bool('M3U8_DOWNLOAD', 'merge_subs')
 CLEANUP_TMP = config_manager.get_bool('M3U8_DOWNLOAD', 'cleanup_tmp_folder')
-FILTER_CUSTOM_REOLUTION = str(config_manager.get('M3U8_PARSER', 'force_resolution')).strip().lower()
-GET_ONLY_LINK = config_manager.get_bool('M3U8_PARSER', 'get_only_link')
+GET_ONLY_LINK = config_manager.get_int('M3U8_DOWNLOAD', 'get_only_link')
+FILTER_CUSTOM_RESOLUTION = str(config_manager.get('M3U8_CONVERSION', 'force_resolution')).strip().lower()
 RETRY_LIMIT = config_manager.get_int('REQUESTS', 'max_retry')
 MAX_TIMEOUT = config_manager.get_int("REQUESTS", "timeout")
 TELEGRAM_BOT = config_manager.get_bool('DEFAULT', 'telegram_bot')
@@ -65,7 +64,8 @@ class HLSClient:
         Returns:
             Response content/text or None if all retries fail
         """
-        client = httpx.Client(headers=self.headers, timeout=MAX_TIMEOUT, follow_redirects=True)
+        client = create_client(headers=self.headers)
+
         for attempt in range(RETRY_LIMIT):
             try:
                 response = client.get(url)
@@ -96,11 +96,6 @@ class PathManager:
         Ensures output path is valid and follows expected format.
         Creates a hash-based filename if no path is provided.
         """
-        if not path:
-            root = config_manager.get('OUT_FOLDER', 'root_path')
-            hash_name = compute_sha1_hash(self.m3u8_url) + ".mp4"
-            return os.path.join(root, "undefined", hash_name)
-
         if not path.endswith(".mp4"):
             path += ".mp4"
 
@@ -156,34 +151,38 @@ class M3U8Manager:
         If it's a master playlist, only selects video stream.
         """
         if not self.is_master:
-            self.video_url, self.video_res = self.m3u8_url, "0p"
+            self.video_url, self.video_res = self.m3u8_url, "undefined"
             self.audio_streams = []
             self.sub_streams = []
 
         else:
-            if str(FILTER_CUSTOM_REOLUTION) == "best":
+            if str(FILTER_CUSTOM_RESOLUTION) == "best":
                 self.video_url, self.video_res = self.parser._video.get_best_uri()
-            elif str(FILTER_CUSTOM_REOLUTION) == "worst":
+            elif str(FILTER_CUSTOM_RESOLUTION) == "worst":
                 self.video_url, self.video_res = self.parser._video.get_worst_uri()
-            elif "p" in str(FILTER_CUSTOM_REOLUTION):
-                self.video_url, self.video_res = self.parser._video.get_custom_uri(int(FILTER_CUSTOM_REOLUTION.replace("p", "")))
+            elif str(FILTER_CUSTOM_RESOLUTION).replace("p", "").replace("px", "").isdigit():
+                resolution_value = int(str(FILTER_CUSTOM_RESOLUTION).replace("p", "").replace("px", ""))
+                self.video_url, self.video_res = self.parser._video.get_custom_uri(resolution_value)
             else:
                 logging.error("Resolution not recognized.")
                 self.video_url, self.video_res = self.parser._video.get_best_uri()
 
-            self.audio_streams = []
-            if ENABLE_AUDIO:
-                self.audio_streams = [
-                    s for s in (self.parser._audio.get_all_uris_and_names() or [])
-                    if s.get('language') in DOWNLOAD_SPECIFIC_AUDIO
-                ]
+            # Audio info
+            self.audio_streams = [
+                s for s in (self.parser._audio.get_all_uris_and_names() or [])
+                if s.get('language') in DOWNLOAD_SPECIFIC_AUDIO
+            ]
 
             self.sub_streams = []
             if ENABLE_SUBTITLE:
-                self.sub_streams = [
-                    s for s in (self.parser._subtitle.get_all_uris_and_names() or [])
-                    if s.get('language') in DOWNLOAD_SPECIFIC_SUBTITLE
-                ]
+                if "*" in DOWNLOAD_SPECIFIC_SUBTITLE:
+                    self.sub_streams = self.parser._subtitle.get_all_uris_and_names() or []
+
+                else:
+                    self.sub_streams = [
+                        s for s in (self.parser._subtitle.get_all_uris_and_names() or [])
+                        if s.get('language') in DOWNLOAD_SPECIFIC_SUBTITLE
+                    ]
 
     def log_selection(self):
         tuple_available_resolution = self.parser._video.get_list_resolution()
@@ -191,7 +190,7 @@ class M3U8Manager:
 
         console.print(
             f"[cyan bold]Video    [/cyan bold] [green]Available:[/green] [purple]{', '.join(list_available_resolution)}[/purple] | "
-            f"[red]Set:[/red] [purple]{FILTER_CUSTOM_REOLUTION}[/purple] | "
+            f"[red]Set:[/red] [purple]{FILTER_CUSTOM_RESOLUTION}[/purple] | "
             f"[yellow]Downloadable:[/yellow] [purple]{self.video_res[0]}x{self.video_res[1]}[/purple]"
         )
 
@@ -209,9 +208,13 @@ class M3U8Manager:
                 f"[red]Set:[/red] {set_codec_info}"
             )
 
+        # Get available subtitles and their languages
         available_subtitles = self.parser._subtitle.get_all_uris_and_names() or []
         available_sub_languages = [sub.get('language') for sub in available_subtitles]
-        downloadable_sub_languages = list(set(available_sub_languages) & set(DOWNLOAD_SPECIFIC_SUBTITLE))
+
+        # If "*" is in DOWNLOAD_SPECIFIC_SUBTITLE, all languages are downloadable
+        downloadable_sub_languages = available_sub_languages if "*" in DOWNLOAD_SPECIFIC_SUBTITLE else list(set(available_sub_languages) & set(DOWNLOAD_SPECIFIC_SUBTITLE))
+
         if available_sub_languages:
             console.print(
                 f"[cyan bold]Subtitle [/cyan bold] [green]Available:[/green] [purple]{', '.join(available_sub_languages)}[/purple] | "
@@ -257,7 +260,7 @@ class DownloadManager:
 
         if result.get('stopped', False):
             self.stopped = True
-        
+
         return self.stopped
 
     def download_audio(self, audio: Dict):
@@ -300,8 +303,8 @@ class DownloadManager:
         Downloads all selected streams (video, audio, subtitles).
         """
         return_stopped = False
-
         video_file = os.path.join(self.temp_dir, 'video', '0.ts')
+
         if not os.path.exists(video_file):
             if self.download_video(video_url):
                 if not return_stopped:
@@ -357,6 +360,7 @@ class MergeManager:
         """
         video_file = os.path.join(self.temp_dir, 'video', '0.ts')
         merged_file = video_file
+        use_shortest = False
 
         if not self.audio_streams and not self.sub_streams:
             merged_file = join_video(
@@ -366,14 +370,14 @@ class MergeManager:
             )
 
         else:
-            if MERGE_AUDIO and self.audio_streams:
+            if self.audio_streams:
                 audio_tracks = [{
                     'path': os.path.join(self.temp_dir, 'audio', a['language'], '0.ts'),
                     'name': a['language']
                 } for a in self.audio_streams]
 
                 merged_audio_path = os.path.join(self.temp_dir, 'merged_audio.mp4')
-                merged_file = join_audios(
+                merged_file, use_shortest = join_audios(
                     video_path=video_file,
                     audio_tracks=audio_tracks,
                     out_path=merged_audio_path,
@@ -393,7 +397,7 @@ class MergeManager:
                     out_path=merged_subs_path
                 )
 
-        return merged_file
+        return merged_file, use_shortest
 
 
 class HLS_Downloader:
@@ -417,8 +421,20 @@ class HLS_Downloader:
                 - is_master: Whether the M3U8 was a master playlist
             Or raises an exception if there's an error
         """
-        console.print(f"[cyan]You can safely stop the download with [bold]Ctrl+c[bold] [cyan] \n")
-        
+
+        if GET_ONLY_LINK:
+            console.print(f"URL: [bold red]{self.m3u8_url}[/bold red]")
+            return {
+                'path': None,
+                'url': self.m3u8_url,
+                'is_master': getattr(self.m3u8_manager, 'is_master', None),
+                'msg': None,
+                'error': None,
+                'stopped': True
+            }
+
+        console.print("[cyan]You can safely stop the download with [bold]Ctrl+c[bold] [cyan] \n")
+
         if TELEGRAM_BOT:
             bot = get_bot_instance()
 
@@ -434,20 +450,8 @@ class HLS_Downloader:
                     'stopped': False
                 }
                 if TELEGRAM_BOT:
-                    bot.send_message(f"Contenuto già scaricato!", None)
+                    bot.send_message("Contenuto già scaricato!", None)
                 return response
-            
-            if GET_ONLY_LINK:
-                console.print(f"URL: [bold red]{self.m3u8_url}[/bold red]")
-                return {
-                    'path': None,
-                    'url': self.m3u8_url,
-                    'is_master': getattr(self.m3u8_manager, 'is_master', None),
-                    'msg': None,
-                    'error': None,
-                    'stopped': True
-                }
-
 
             self.path_manager.setup_directories()
 
@@ -476,9 +480,9 @@ class HLS_Downloader:
                 sub_streams=self.m3u8_manager.sub_streams
             )
 
-            final_file = self.merge_manager.merge()
+            final_file, use_shortest = self.merge_manager.merge()
             self.path_manager.move_final_file(final_file)
-            self._print_summary()
+            self._print_summary(use_shortest)
             self.path_manager.cleanup()
 
             return {
@@ -504,7 +508,7 @@ class HLS_Downloader:
                 'stopped': False
             }
 
-    def _print_summary(self):
+    def _print_summary(self, use_shortest):
         """Prints download summary including file size, duration, and any missing segments."""
         if TELEGRAM_BOT:
             bot = get_bot_instance()
@@ -514,7 +518,7 @@ class HLS_Downloader:
         for item in self.download_manager.missing_segments:
             if int(item['nFailed']) >= 1:
                 missing_ts = True
-                missing_info += f"[red]TS Failed: {item['nFailed']} {item['type']} tracks[/red]\n"
+                missing_info += f"[red]TS Failed: {item['nFailed']} {item['type']} tracks[/red]"
 
         file_size = internet_manager.format_file_size(os.path.getsize(self.path_manager.output_path))
         duration = print_duration_table(self.path_manager.output_path, description=False, return_string=True)
@@ -532,10 +536,21 @@ class HLS_Downloader:
 
         if missing_ts:
             panel_content += f"\n{missing_info}"
-            os.rename(self.path_manager.output_path, self.path_manager.output_path.replace(".mp4", "_failed.mp4"))
+
+        new_filename = self.path_manager.output_path
+        if missing_ts and use_shortest:
+            new_filename = new_filename.replace(".mp4", "_failed_sync_ts.mp4")
+        elif missing_ts:
+            new_filename = new_filename.replace(".mp4", "_failed_ts.mp4")
+        elif use_shortest:
+            new_filename = new_filename.replace(".mp4", "_failed_sync.mp4")
+
+        if missing_ts or use_shortest:
+            os.rename(self.path_manager.output_path, new_filename)
+            self.path_manager.output_path = new_filename
 
         console.print(Panel(
             panel_content,
             title=f"{os.path.basename(self.path_manager.output_path.replace('.mp4', ''))}",
             border_style="green"
-        ))
\ No newline at end of file
+        ))
