@@ -23,7 +23,8 @@ from rich.console import Console
 # Internal utilities
 from StreamingCommunity.Util.color import Colors
 from StreamingCommunity.Util.headers import get_userAgent
-from StreamingCommunity.Util.config_json import config_manager, get_use_large_bar
+from StreamingCommunity.Util.http_client import create_client
+from StreamingCommunity.Util.config_json import config_manager
 
 
 # Logic class
@@ -35,16 +36,15 @@ from ...M3U8 import (
 )
 
 # Config
-TQDM_DELAY_WORKER = config_manager.get_float('M3U8_DOWNLOAD', 'tqdm_delay')
+TQDM_DELAY_WORKER = 0.01
 REQUEST_MAX_RETRY = config_manager.get_int('REQUESTS', 'max_retry')
 REQUEST_VERIFY = config_manager.get_bool('REQUESTS', 'verify')
-DEFAULT_VIDEO_WORKERS = config_manager.get_int('M3U8_DOWNLOAD', 'default_video_workser')
-DEFAULT_AUDIO_WORKERS = config_manager.get_int('M3U8_DOWNLOAD', 'default_audio_workser')
+DEFAULT_VIDEO_WORKERS = config_manager.get_int('M3U8_DOWNLOAD', 'default_video_workers')
+DEFAULT_AUDIO_WORKERS = config_manager.get_int('M3U8_DOWNLOAD', 'default_audio_workers')
 MAX_TIMEOOUT = config_manager.get_int("REQUESTS", "timeout")
-MAX_INTERRUPT_COUNT = 3
 SEGMENT_MAX_TIMEOUT = config_manager.get_int("M3U8_DOWNLOAD", "segment_timeout")
 TELEGRAM_BOT = config_manager.get_bool('DEFAULT', 'telegram_bot')
-
+MAX_INTERRUPT_COUNT = 3
 
 # Variable
 console = Console()
@@ -111,7 +111,7 @@ class M3U8_Segments:
         self.key_base_url = f"{parsed_url.scheme}://{parsed_url.netloc}/"
         
         try:
-            client_params = {'headers': {'User-Agent': get_userAgent()}, 'timeout': MAX_TIMEOOUT}
+            client_params = {'headers': {'User-Agent': get_userAgent()}, 'timeout': MAX_TIMEOOUT, 'verify': REQUEST_VERIFY}
             response = httpx.get(url=key_uri, **client_params)
             response.raise_for_status()
 
@@ -159,8 +159,8 @@ class M3U8_Segments:
         """
         if self.is_index_url:
             try:
-                client_params = {'headers': {'User-Agent': get_userAgent()}, 'timeout': MAX_TIMEOOUT}
-                response = httpx.get(self.url, **client_params)
+                client_params = {'headers': {'User-Agent': get_userAgent()}, 'timeout': MAX_TIMEOOUT, 'verify': REQUEST_VERIFY}
+                response = httpx.get(self.url, **client_params, follow_redirects=True)
                 response.raise_for_status()
                 
                 self.parse_data(response.text)
@@ -199,13 +199,7 @@ class M3U8_Segments:
             print("Signal handler must be set in the main thread")
 
     def _get_http_client(self):
-        client_params = {
-            'headers': {'User-Agent': get_userAgent()},
-            'timeout': SEGMENT_MAX_TIMEOUT,
-            'follow_redirects': True,
-            'http2': False
-        }
-        return httpx.Client(**client_params)
+        return create_client(headers={'User-Agent': get_userAgent()}, follow_redirects=True)
                             
     def download_segment(self, ts_url: str, index: int, progress_bar: tqdm, backoff_factor: float = 1.1) -> None:
         """
@@ -255,7 +249,7 @@ class M3U8_Segments:
                 self.info_nRetry += 1
 
                 if attempt + 1 == REQUEST_MAX_RETRY:
-                    console.log(f"[red]Final retry failed for segment: {index}")
+                    console.print(f"[red]Final retry failed for segment: {index}")
                     self.queue.put((index, None))  # Marker for failed segment
                     progress_bar.update(1)
                     self.info_nFailed += 1
@@ -264,7 +258,8 @@ class M3U8_Segments:
                 with self.active_retries_lock:
                     self.active_retries += 1
                 
-                sleep_time = backoff_factor * (2 ** attempt)
+                #sleep_time = backoff_factor * (2 ** attempt)
+                sleep_time = backoff_factor * (attempt + 1)
                 logging.info(f"Retrying segment {index} in {sleep_time} seconds...")
                 time.sleep(sleep_time)
                 
@@ -408,20 +403,12 @@ class M3U8_Segments:
         """
         Generate platform-appropriate progress bar format.
         """
-        if not get_use_large_bar():
-            return (
-                f"{Colors.YELLOW}Proc{Colors.WHITE}: "
-                f"{Colors.RED}{{percentage:.2f}}% "
-                f"{Colors.CYAN}{{remaining}}{{postfix}} {Colors.WHITE}]"
-            )
-            
-        else:
-            return (
-                f"{Colors.YELLOW}[HLS] {Colors.WHITE}({Colors.CYAN}{description}{Colors.WHITE}): "
-                f"{Colors.RED}{{percentage:.2f}}% "
-                f"{Colors.MAGENTA}{{bar}} "
-                f"{Colors.YELLOW}{{elapsed}}{Colors.WHITE} < {Colors.CYAN}{{remaining}}{Colors.WHITE}{{postfix}}{Colors.WHITE}"
-            )
+        return (
+            f"{Colors.YELLOW}[HLS] {Colors.WHITE}({Colors.CYAN}{description}{Colors.WHITE}): "
+            f"{Colors.RED}{{percentage:.2f}}% "
+            f"{Colors.MAGENTA}{{bar}} "
+            f"{Colors.YELLOW}{{elapsed}}{Colors.WHITE} < {Colors.CYAN}{{remaining}}{Colors.WHITE}{{postfix}}{Colors.WHITE}"
+        )
     
     def _get_worker_count(self, stream_type: str) -> int:
         """
@@ -455,9 +442,6 @@ class M3U8_Segments:
         writer_thread.join(timeout=30)
         progress_bar.close()
         
-        #if self.download_interrupted:
-        #    console.print("\n[red]Download terminated by user")
-            
         if self.info_nFailed > 0:
             self._display_error_summary()
 
@@ -472,4 +456,4 @@ class M3U8_Segments:
                      f"[white]Failed segments: [red]{self.info_nFailed}")
         
         if self.info_nRetry > len(self.segments) * 0.3:
-            console.print("[yellow]Warning: High retry count detected. Consider reducing worker count in config.")
\ No newline at end of file
+            console.print("[yellow]Warning: High retry count detected. Consider reducing worker count in config.")
